``zope.password``
=================

.. image:: https://img.shields.io/pypi/v/zope.password.svg
    :target: https://pypi.python.org/pypi/zope.password/
    :alt: Latest Version

.. image:: https://travis-ci.org/zopefoundation/zope.password.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.password

.. image:: https://readthedocs.org/projects/zopepassword/badge/?version=latest
        :target: http://zopepassword.readthedocs.org/en/latest/
        :alt: Documentation Status

This package provides a password manager mechanism. Password manager
is an utility object that can encode and check encoded
passwords.
